==> haskell-iwlib-0.1.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iwlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 iwlib
version:              0.1.0
visibility:           public
id:                   iwlib-0.1.0-BNSGOfAOzsXG4iRuj4ZwOm
key:                  iwlib-0.1.0-BNSGOfAOzsXG4iRuj4ZwOm
license:              BSD-3-Clause
maintainer:           Jose Antonio Ortega Ruiz <jao@gnu.org>
author:               Jose Antonio Ortega Ruiz <jao@gnu.org>
homepage:             https://github.com/jaor/iwlib
synopsis:             Bindings for the iw C library
description:
    A binding to the iw library for getting info about the current WiFi connection.

category:             System, Network
abi:                  81382e8c8f8e3d4479eb039dd2028746
exposed:              True
exposed-modules:      Network.IWlib
import-dirs:          /usr/lib/ghc-8.10.1/site-local/iwlib-0.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/iwlib-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/iwlib-0.1.0
hs-libraries:         HSiwlib-0.1.0-BNSGOfAOzsXG4iRuj4ZwOm
extra-libraries:      iw
includes:             iwlib.h
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-iwlib/html/iwlib.haddock
haddock-html:         /usr/share/doc/haskell-iwlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iwlib-0.1.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iwlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 iwlib
version:              0.1.0
visibility:           public
id:                   iwlib-0.1.0-DglkiQSSSPL8Bp8GnihHb8
key:                  iwlib-0.1.0-DglkiQSSSPL8Bp8GnihHb8
license:              BSD-3-Clause
maintainer:           Jose Antonio Ortega Ruiz <jao@gnu.org>
author:               Jose Antonio Ortega Ruiz <jao@gnu.org>
homepage:             https://github.com/jaor/iwlib
synopsis:             Bindings for the iw C library
description:
    A binding to the iw library for getting info about the current WiFi connection.

category:             System, Network
abi:                  770938ac33716ef14ab4e3c8edb2c259
exposed:              True
exposed-modules:      Network.IWlib
import-dirs:          /usr/lib/ghc-8.10.2/site-local/iwlib-0.1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/iwlib-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/iwlib-0.1.0
hs-libraries:         HSiwlib-0.1.0-DglkiQSSSPL8Bp8GnihHb8
extra-libraries:      iw
includes:             iwlib.h
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-iwlib/html/iwlib.haddock
haddock-html:         /usr/share/doc/haskell-iwlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
